@@ -3,12 +3,15 @@
 #' Generate an EQF plot based on the result of the permutation process
 #' used to detect the QTL hotspot.
 #'
-#' @param result list. The data list of the output from LOD.QTLdetect()
-#' or EQF.permu().
+#' @param result list. The data list of the output from LOD.QTLdetect(),
+#' EQF.permu(), or Qhot.EQF().
 #' @param plot.all logical. When set to TRUE, it directs the function to
 #' output one figure of the EQF values over the bins.
 #' @param plot.chr logical. When set to TRUE, it instructs the function to
 #' output the figures of the EQF values over the bins for each chromosome.
+#' @param plot.main logical of character. When set to TRUE, it will use the
+#' default title on the plot. When set to FALSE, it will be no title on the
+#' plot. Users can also use this argument to set their own title.
 #'
 #' @return
 #'
@@ -33,32 +36,37 @@
 #' # run and result
 #' EQF.plot(LOD.QTLdetect.result)
 #' EQF.plot(EQF.permu.result)
-EQF.plot <- function(result, plot.all = TRUE, plot.chr = TRUE){
+EQF.plot <- function(result, plot.all = TRUE, plot.chr = TRUE, plot.main = TRUE){
 
   dat <- result
   name0 <- names(dat)
   if(length(name0) == 6){
     datatest <- name0 != c("detect.QTL.number", "QTL.matrix", "EQF.matrix",
                            "linkage.QTL.number", "LOD.threshold", "bin")
-  } else if (length(name0) == 9){
+  } else if(length(name0) == 9){
     datatest <- name0 != c("EQF.matrix", "bin", "LOD.threshold", "cluster.number", "cluster.id",
                            "cluster.matrix", "permu.matrix.cluster", "permu.matrix.Q", "EQF.threshold")
+  } else if(length(name0) == 10){
+    datatest <- name0 != c("EQF.matrix", "bin", "bin.size", "EQF.trait", "EQF.detect", "EQF.nondetect",
+                           "cluster.matrix", "permu.matrix.cluster", "permu.matrix.Q", "EQF.threshold")
   } else {
-    stop("Input data error, please input the original output data of LOD.QTLdetect or EQF.permu.", call. = FALSE)
+    stop("Input data error, please input the original output data of LOD.QTLdetect, EQF.permu ,or Qhot.EQF.", call. = FALSE)
   }
 
   if(TRUE %in% (datatest)){
-    stop("Input data error, please input the original output data of LOD.QTLdetect or EQF.permu.", call. = FALSE)
+    stop("Input data error, please input the original output data of LOD.QTLdetect, EQF.permu ,or Qhot.EQF.", call. = FALSE)
   }
 
   if(!plot.all[1] %in% c(0,1) | length(plot.all) > 1){plot.all <- TRUE}
   if(!plot.chr[1] %in% c(0,1) | length(plot.chr) > 1){plot.chr <- TRUE}
+  if(length(plot.main) > 1){plot.main <- TRUE}
 
   EQF <- dat$EQF.matrix
   clumatrix <- dat$cluster.matrix
   thre <- dat$LOD.threshold
   eqfthre <- dat$EQF.threshold
   bin <- dat$bin
+  bin.size <- dat$bin.size
   nc <- nrow(bin)
   lcr <- bin[, 2]
   ncr <- c()
@@ -87,13 +95,33 @@ EQF.plot <- function(result, plot.all = TRUE, plot.chr = TRUE){
   if(plot.all & nc>1){
     graphics::par(mfrow = c(1, 1))
     graphics::par(mai = c(1, 1, 1, 1))
-    ma <- paste("LOD threshold =", thre)
-    if(length(clumatrix) > 0){
-      ma <- paste("LOD threshold =", thre, "  # of group =", nrow(clumatrix))
-      graphics::par(mai = c(1, 1, 1, 1.5))
+
+    if(plot.main==TRUE){
+      if(is.null(bin.size)){
+        ma1 <- paste("LOD threshold =", thre)
+        ma <- "EQF plot from LOD data"
+      } else {
+        ma1 <- paste("bin size =", bin.size)
+        ma <- "EQF plot from flanking marker data"
+      }
+      if(length(clumatrix) > 0){
+        ma2 <- paste("  # of group =", nrow(clumatrix))
+        graphics::par(mai = c(1, 1, 1, 1.5))
+      } else {
+        ma2 <- NULL
+      }
+      masb <- paste(ma1, ma2)
+    } else if(plot.main==FALSE) {
+      ma <- NULL
+      masb <- NULL
+    } else {
+      ma <- plot.main
+      masb <- NULL
     }
+
     plot(x0, eqf.all, type = "h", ylab = "EQF", xlab = "chromosome", main = ma,
          xaxt = "n", ylim = c(0, yli), yaxt = "n",  cex.main = 1.5, cex.lab = 1.2, axes = FALSE)
+    graphics::mtext(masb, side = 3, line = 0.5, cex = 1.2)
     graphics::axis(side = 1, pos = -yli/35, at = xn, labels = 1:nc, cex.axis = 1.2, tick = FALSE)
     lse <- 4000/max(x0)
     graphics::segments(x0, rep(-yli/35, length(x0)), x0, rep(-yli/70, length(x0)), lwd = lse)
@@ -107,7 +135,7 @@ EQF.plot <- function(result, plot.all = TRUE, plot.chr = TRUE){
         graphics::axis(4, paste(rownames(eqfthre)[j], " (", eqfthre[j, 2], ")", sep = ""), at = eqfthre[j], las = 2)
       }
       graphics::abline(h = eqfthre[, 1], col = "red")
-    } else {graphics::axis(2, seq(0, yli, 2), las = 2)}
+    } else {graphics::axis(2, seq(0, yli, 5), las = 2)}
   }
 
   if(plot.chr | (nc == 1 & plot.all)){
@@ -122,17 +150,36 @@ EQF.plot <- function(result, plot.all = TRUE, plot.chr = TRUE){
         graphics::par(mai = c(1, 1, 1, 1))
       }
     }
+
+    if(plot.main==TRUE){
+      if(is.null(bin.size)){
+        ma1 <- paste(", LOD threshold =", thre)
+        ma <- "EQF plot from LOD data"
+      } else {
+        ma1 <- paste(", bin size =", bin.size)
+        ma <- "EQF plot from flanking marker data"
+      }
+    } else if(plot.main==FALSE) {
+      ma <- NULL
+      ma1 <- NULL
+    } else {
+      ma <- plot.main
+      ma1 <- NULL
+    }
+
     for(i in 1:nc){
       eqf <- eqf.all[cr0 == i]
-      plot(eqf, type = "h", ylab = "EQF", xlab = "position (bin)", main = paste("chr", i, "   LOD threshold = ", thre),
+      plot(eqf, type = "h", ylab = "EQF", xlab = "position (bin)", main = ma,
            ylim = c(0, max(eqf.all)*1.2), yaxt = "n", cex.main = 1.5, cex.lab = 1.2)
+      masb <- paste("chr ", i, ma1, sep = "")
+      graphics::mtext(masb, side = 3, line = 0.3, cex = 1.2)
       if(length(eqfthre)>0){
         for(k in 1:nrow(eqfthre)){
           graphics::axis(2, eqfthre[k, 1], las = 2.5)
           graphics::axis(4, paste(rownames(eqfthre)[k], " (", eqfthre[k, 2], ")", sep = ""), at = eqfthre[k], las = 2.5)
         }
         graphics::abline(h = eqfthre[, 1], col = "red")
-      } else {graphics::axis(2, seq(0, yli, 2), las = 2.5)}
+      } else {graphics::axis(2, seq(0, yli, 5), las = 2.5)}
     }
   }
 }
